<?php

namespace Litepci\Requirement\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepci\Requirement\Interfaces\FamilyRepositoryInterface;

class FamilyPublicController extends BaseController
{
    // use FamilyWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepci\Family\Interfaces\FamilyRepositoryInterface $family
     *
     * @return type
     */
    public function __construct(FamilyRepositoryInterface $family)
    {
        $this->repository = $family;
        parent::__construct();
    }

    /**
     * Show family's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $families = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$requirement::$family.names'))
            ->view('$requirement::public.family.index')
            ->data(compact('$families'))
            ->output();
    }

    /**
     * Show family's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $families = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$requirement::$family.names'))
            ->view('$requirement::public.family.index')
            ->data(compact('$families'))
            ->output();
    }

    /**
     * Show family.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $family = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$family->name . trans('$requirement::$family.name'))
            ->view('$requirement::public.family.show')
            ->data(compact('$family'))
            ->output();
    }

}
