<?php

namespace Litepci\Requirement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Requirement\Models\Family;

class FamilyPolicy
{

    /**
     * Determine if the given user can view the family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function view(UserPolicy $user, Family $family)
    {
        if ($user->canDo('requirement.family.view') && $user->isAdmin()) {
            return true;
        }

        return $family->user_id == user_id() && $family->user_type == user_type();
    }

    /**
     * Determine if the given user can create a family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('requirement.family.create');
    }

    /**
     * Determine if the given user can update the given family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function update(UserPolicy $user, Family $family)
    {
        if ($user->canDo('requirement.family.edit') && $user->isAdmin()) {
            return true;
        }

        return $family->user_id == user_id() && $family->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Family $family)
    {
        return $family->user_id == user_id() && $family->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Family $family)
    {
        if ($user->canDo('requirement.family.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given family.
     *
     * @param UserPolicy $user
     * @param Family $family
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Family $family)
    {
        if ($user->canDo('requirement.family.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
