<?php

namespace Litepci\Requirement\Providers;

use Illuminate\Support\ServiceProvider;

class RequirementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'requirement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'requirement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litepci.requirement', function ($app) {
            return $this->app->make('Litepci\Requirement\Requirement');
        });

                // Bind Family to repository
        $this->app->bind(
            'Litepci\Requirement\Interfaces\FamilyRepositoryInterface',
            \Litepci\Requirement\Repositories\Eloquent\FamilyRepository::class
        );

        $this->app->register(\Litepci\Requirement\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Requirement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.requirement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/requirement.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/requirement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/requirement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
